==> ogre_1.7.4+dfsg1.orig.tar.xz: ogre-1.7.4+dfsg1/Tests/Components/Paging/include/PageCoreTests.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
(Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2011 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/
#include <cppunit/TestFixture.h>
#include <cppunit/extensions/HelperMacros.h>

#include "OgreRoot.h"
#include "OgrePageManager.h"
#include "OgreGrid2DPageStrategy.h"

using namespace Ogre; 

class PageCoreTests : public CppUnit::TestFixture
{
	// CppUnit macros for setting up the test suite
	CPPUNIT_TEST_SUITE( PageCoreTests );
	CPPUNIT_TEST(testSimpleCreateSaveLoadWorld);
	CPPUNIT_TEST_SUITE_END();

	Root* mRoot;
	PageManager* mPageManager;
	SceneManager* mSceneMgr;
public:
	void setUp();
	void tearDown();
	void testSimpleCreateSaveLoadWorld();
	void testLoadWorld();
};

==> ogre-1.9_1.9.0+dfsg1.orig.tar.xz: ogre-1.9.0/Tests/Components/Paging/include/PageCoreTests.h <==
/*
-----------------------------------------------------------------------------
This source file is part of OGRE
(Object-oriented Graphics Rendering Engine)
For the latest info, see http://www.ogre3d.org/

Copyright (c) 2000-2013 Torus Knot Software Ltd

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
-----------------------------------------------------------------------------
*/
#include <cppunit/TestFixture.h>
#include <cppunit/extensions/HelperMacros.h>

#include "OgreRoot.h"
#include "OgrePageManager.h"
#include "OgreGrid2DPageStrategy.h"

#ifdef OGRE_STATIC_LIB
#include "../../../../Samples/Common/include/OgreStaticPluginLoader.h"
#endif

using namespace Ogre; 

class PageCoreTests : public CppUnit::TestFixture
{
	// CppUnit macros for setting up the test suite
	CPPUNIT_TEST_SUITE( PageCoreTests );
	CPPUNIT_TEST(testSimpleCreateSaveLoadWorld);
	CPPUNIT_TEST_SUITE_END();

	Root* mRoot;
	PageManager* mPageManager;
	SceneManager* mSceneMgr;
#ifdef OGRE_STATIC_LIB
	StaticPluginLoader mStaticPluginLoader;
#endif

public:
	void setUp();
	void tearDown();
	void testSimpleCreateSaveLoadWorld();
	void testLoadWorld();
};
